feedgen.ext.base — python-feedgen 0.2.8 documentation

# python-feedgen 0.2.8 documentation

## feedgen.ext.base

Contents

# feedgen.ext.base

Basic FeedGenerator extension which does nothing but provides all necessary methods.

copyright: | 2013, Lars Kiesow <lkiesow@uos.de>
license: | FreeBSD and LGPL, see license.* for more details.

class `feedgen.ext.base.` `BaseEntryExtension`

  Basic FeedEntry extension.

class `feedgen.ext.base.` `BaseExtension`

  Basic FeedGenerator extension.

  `extend_atom`(feed)

    Create an ATOM feed xml structure containing all previously set fields.

    Parameters: | feed – The feed xml root element.
    Returns: | The feed root element.

  `extend_rss`(feed)

    Create an RSS feed xml structure containing all previously set fields.

    Parameters: | feed – The feed xml root element.
    Returns: | The feed root element.